package fi.hsivonen.photobackup;

import java.util.HashMap;
import java.util.Map;

import nu.validator.xml.EmptyAttributes;

import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

public class PhotoFilter extends RootlessRestResponseContentHandlerFilter {

    private final String id;

    private final FlickrEntityResolver resolver;

    private final Map<String, String> photourls;

    private boolean inComment = false;

    private final StringBuilder buf = new StringBuilder();

    public PhotoFilter(ContentHandler delegate, String id,
            FlickrEntityResolver resolver, Map<String, String> photourls) {
        super(delegate);
        this.id = id;
        this.resolver = resolver;
        this.photourls = photourls;
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#endElement(java.lang.String,
     *      java.lang.String, java.lang.String)
     */
    @Override
    public void endElement(String uri, String localName, String qName)
            throws SAXException {
        if (uri == "" && localName == "comments") {
            inComment = false;
            if ("0".equals(buf.toString().trim())) {
                delegate.startElement("", "comments", "comments",
                        EmptyAttributes.EMPTY_ATTRIBUTES);
                delegate.endElement("", "comments", "comments");
            } else {
                Map<String, Object> arguments = new HashMap<String, Object>();
                arguments.put("photo_id", id);
                System.out.println("Retrieving comments for photo " + id);
                resolver.callApi(new RootlessRestResponseContentHandlerFilter(
                        delegate), "flickr.photos.comments.getList", arguments);
            }
        } else {
            super.endElement(uri, localName, qName);
        }
        
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#startElement(java.lang.String,
     *      java.lang.String, java.lang.String, org.xml.sax.Attributes)
     */
    @Override
    public void startElement(String uri, String localName, String qName,
            Attributes atts) throws SAXException {
        if (uri == "" && localName == "comments") {
            inComment = true;
            buf.setLength(0);
        } else {
            if (uri == "" && localName == "photo") {
                photourls.put("http://farm" + atts.getValue("", "farm")
                        + ".static.flickr.com/" + atts.getValue("", "server")
                        + "/" + id + "_" + atts.getValue("", "originalsecret")
                        + "_o." + atts.getValue("", "originalformat"), id + "_"
                        + atts.getValue("", "originalsecret") + "_o."
                        + atts.getValue("", "originalformat"));
            }
            super.startElement(uri, localName, qName, atts);
        }
    }

    /**
     * @see fi.hsivonen.photobackup.RootlessRestResponseContentHandlerFilter#characters(char[],
     *      int, int)
     */
    @Override
    public void characters(char[] ch, int start, int length)
            throws SAXException {
        if (inComment) {
            buf.append(ch, start, length);
        } else {
            super.characters(ch, start, length);
        }
    }

}
